# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DependentObjectSummary(object):
    """
    Details of the dependent object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DependentObjectSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param created_by:
            The value to assign to the created_by property of this DependentObjectSummary.
        :type created_by: str

        :param created_by_name:
            The value to assign to the created_by_name property of this DependentObjectSummary.
        :type created_by_name: str

        :param updated_by:
            The value to assign to the updated_by property of this DependentObjectSummary.
        :type updated_by: str

        :param updated_by_name:
            The value to assign to the updated_by_name property of this DependentObjectSummary.
        :type updated_by_name: str

        :param time_created:
            The value to assign to the time_created property of this DependentObjectSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DependentObjectSummary.
        :type time_updated: datetime

        :param aggregator_key:
            The value to assign to the aggregator_key property of this DependentObjectSummary.
        :type aggregator_key: str

        :param identifier_path:
            The value to assign to the identifier_path property of this DependentObjectSummary.
        :type identifier_path: str

        :param info_fields:
            The value to assign to the info_fields property of this DependentObjectSummary.
        :type info_fields: dict(str, str)

        :param registry_version:
            The value to assign to the registry_version property of this DependentObjectSummary.
        :type registry_version: int

        :param labels:
            The value to assign to the labels property of this DependentObjectSummary.
        :type labels: list[str]

        """
        self.swagger_types = {
            'created_by': 'str',
            'created_by_name': 'str',
            'updated_by': 'str',
            'updated_by_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'aggregator_key': 'str',
            'identifier_path': 'str',
            'info_fields': 'dict(str, str)',
            'registry_version': 'int',
            'labels': 'list[str]'
        }

        self.attribute_map = {
            'created_by': 'createdBy',
            'created_by_name': 'createdByName',
            'updated_by': 'updatedBy',
            'updated_by_name': 'updatedByName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'aggregator_key': 'aggregatorKey',
            'identifier_path': 'identifierPath',
            'info_fields': 'infoFields',
            'registry_version': 'registryVersion',
            'labels': 'labels'
        }

        self._created_by = None
        self._created_by_name = None
        self._updated_by = None
        self._updated_by_name = None
        self._time_created = None
        self._time_updated = None
        self._aggregator_key = None
        self._identifier_path = None
        self._info_fields = None
        self._registry_version = None
        self._labels = None

    @property
    def created_by(self):
        """
        Gets the created_by of this DependentObjectSummary.
        The user that created the object.


        :return: The created_by of this DependentObjectSummary.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this DependentObjectSummary.
        The user that created the object.


        :param created_by: The created_by of this DependentObjectSummary.
        :type: str
        """
        self._created_by = created_by

    @property
    def created_by_name(self):
        """
        Gets the created_by_name of this DependentObjectSummary.
        The user that created the object.


        :return: The created_by_name of this DependentObjectSummary.
        :rtype: str
        """
        return self._created_by_name

    @created_by_name.setter
    def created_by_name(self, created_by_name):
        """
        Sets the created_by_name of this DependentObjectSummary.
        The user that created the object.


        :param created_by_name: The created_by_name of this DependentObjectSummary.
        :type: str
        """
        self._created_by_name = created_by_name

    @property
    def updated_by(self):
        """
        Gets the updated_by of this DependentObjectSummary.
        The user that updated the object.


        :return: The updated_by of this DependentObjectSummary.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this DependentObjectSummary.
        The user that updated the object.


        :param updated_by: The updated_by of this DependentObjectSummary.
        :type: str
        """
        self._updated_by = updated_by

    @property
    def updated_by_name(self):
        """
        Gets the updated_by_name of this DependentObjectSummary.
        The user that updated the object.


        :return: The updated_by_name of this DependentObjectSummary.
        :rtype: str
        """
        return self._updated_by_name

    @updated_by_name.setter
    def updated_by_name(self, updated_by_name):
        """
        Sets the updated_by_name of this DependentObjectSummary.
        The user that updated the object.


        :param updated_by_name: The updated_by_name of this DependentObjectSummary.
        :type: str
        """
        self._updated_by_name = updated_by_name

    @property
    def time_created(self):
        """
        Gets the time_created of this DependentObjectSummary.
        The date and time that the object was created.


        :return: The time_created of this DependentObjectSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DependentObjectSummary.
        The date and time that the object was created.


        :param time_created: The time_created of this DependentObjectSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DependentObjectSummary.
        The date and time that the object was updated.


        :return: The time_updated of this DependentObjectSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DependentObjectSummary.
        The date and time that the object was updated.


        :param time_updated: The time_updated of this DependentObjectSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def aggregator_key(self):
        """
        Gets the aggregator_key of this DependentObjectSummary.
        The owning object key for this object.


        :return: The aggregator_key of this DependentObjectSummary.
        :rtype: str
        """
        return self._aggregator_key

    @aggregator_key.setter
    def aggregator_key(self, aggregator_key):
        """
        Sets the aggregator_key of this DependentObjectSummary.
        The owning object key for this object.


        :param aggregator_key: The aggregator_key of this DependentObjectSummary.
        :type: str
        """
        self._aggregator_key = aggregator_key

    @property
    def identifier_path(self):
        """
        Gets the identifier_path of this DependentObjectSummary.
        The full path to identify this object.


        :return: The identifier_path of this DependentObjectSummary.
        :rtype: str
        """
        return self._identifier_path

    @identifier_path.setter
    def identifier_path(self, identifier_path):
        """
        Sets the identifier_path of this DependentObjectSummary.
        The full path to identify this object.


        :param identifier_path: The identifier_path of this DependentObjectSummary.
        :type: str
        """
        self._identifier_path = identifier_path

    @property
    def info_fields(self):
        """
        Gets the info_fields of this DependentObjectSummary.
        infoFields


        :return: The info_fields of this DependentObjectSummary.
        :rtype: dict(str, str)
        """
        return self._info_fields

    @info_fields.setter
    def info_fields(self, info_fields):
        """
        Sets the info_fields of this DependentObjectSummary.
        infoFields


        :param info_fields: The info_fields of this DependentObjectSummary.
        :type: dict(str, str)
        """
        self._info_fields = info_fields

    @property
    def registry_version(self):
        """
        Gets the registry_version of this DependentObjectSummary.
        registryVersion


        :return: The registry_version of this DependentObjectSummary.
        :rtype: int
        """
        return self._registry_version

    @registry_version.setter
    def registry_version(self, registry_version):
        """
        Sets the registry_version of this DependentObjectSummary.
        registryVersion


        :param registry_version: The registry_version of this DependentObjectSummary.
        :type: int
        """
        self._registry_version = registry_version

    @property
    def labels(self):
        """
        Gets the labels of this DependentObjectSummary.
        Labels are keywords or tags that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :return: The labels of this DependentObjectSummary.
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this DependentObjectSummary.
        Labels are keywords or tags that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :param labels: The labels of this DependentObjectSummary.
        :type: list[str]
        """
        self._labels = labels

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FailureDetails(object):
    """
    FailureDetails model.
    """

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "INTERNAL_SERVICE_ERROR"
    CODE_INTERNAL_SERVICE_ERROR = "INTERNAL_SERVICE_ERROR"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "TERRAFORM_EXECUTION_ERROR"
    CODE_TERRAFORM_EXECUTION_ERROR = "TERRAFORM_EXECUTION_ERROR"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "TERRAFORM_CONFIG_UNZIP_FAILED"
    CODE_TERRAFORM_CONFIG_UNZIP_FAILED = "TERRAFORM_CONFIG_UNZIP_FAILED"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "INVALID_WORKING_DIRECTORY"
    CODE_INVALID_WORKING_DIRECTORY = "INVALID_WORKING_DIRECTORY"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "JOB_TIMEOUT"
    CODE_JOB_TIMEOUT = "JOB_TIMEOUT"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "TERRAFORM_CONFIG_VIRUS_FOUND"
    CODE_TERRAFORM_CONFIG_VIRUS_FOUND = "TERRAFORM_CONFIG_VIRUS_FOUND"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "TERRAFORM_GIT_CLONE_FAILURE"
    CODE_TERRAFORM_GIT_CLONE_FAILURE = "TERRAFORM_GIT_CLONE_FAILURE"

    #: A constant which can be used with the code property of a FailureDetails.
    #: This constant has a value of "TERRAFORM_GIT_CHECKOUT_FAILURE"
    CODE_TERRAFORM_GIT_CHECKOUT_FAILURE = "TERRAFORM_GIT_CHECKOUT_FAILURE"

    def __init__(self, **kwargs):
        """
        Initializes a new FailureDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param code:
            The value to assign to the code property of this FailureDetails.
            Allowed values for this property are: "INTERNAL_SERVICE_ERROR", "TERRAFORM_EXECUTION_ERROR", "TERRAFORM_CONFIG_UNZIP_FAILED", "INVALID_WORKING_DIRECTORY", "JOB_TIMEOUT", "TERRAFORM_CONFIG_VIRUS_FOUND", "TERRAFORM_GIT_CLONE_FAILURE", "TERRAFORM_GIT_CHECKOUT_FAILURE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type code: str

        :param message:
            The value to assign to the message property of this FailureDetails.
        :type message: str

        """
        self.swagger_types = {
            'code': 'str',
            'message': 'str'
        }

        self.attribute_map = {
            'code': 'code',
            'message': 'message'
        }

        self._code = None
        self._message = None

    @property
    def code(self):
        """
        **[Required]** Gets the code of this FailureDetails.
        Job failure reason.

        Allowed values for this property are: "INTERNAL_SERVICE_ERROR", "TERRAFORM_EXECUTION_ERROR", "TERRAFORM_CONFIG_UNZIP_FAILED", "INVALID_WORKING_DIRECTORY", "JOB_TIMEOUT", "TERRAFORM_CONFIG_VIRUS_FOUND", "TERRAFORM_GIT_CLONE_FAILURE", "TERRAFORM_GIT_CHECKOUT_FAILURE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The code of this FailureDetails.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this FailureDetails.
        Job failure reason.


        :param code: The code of this FailureDetails.
        :type: str
        """
        allowed_values = ["INTERNAL_SERVICE_ERROR", "TERRAFORM_EXECUTION_ERROR", "TERRAFORM_CONFIG_UNZIP_FAILED", "INVALID_WORKING_DIRECTORY", "JOB_TIMEOUT", "TERRAFORM_CONFIG_VIRUS_FOUND", "TERRAFORM_GIT_CLONE_FAILURE", "TERRAFORM_GIT_CHECKOUT_FAILURE"]
        if not value_allowed_none_or_none_sentinel(code, allowed_values):
            code = 'UNKNOWN_ENUM_VALUE'
        self._code = code

    @property
    def message(self):
        """
        **[Required]** Gets the message of this FailureDetails.
        A human-readable error string.


        :return: The message of this FailureDetails.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this FailureDetails.
        A human-readable error string.


        :param message: The message of this FailureDetails.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemSummary(object):
    """
    A summary of a DB System.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DbSystemSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DbSystemSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this DbSystemSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DbSystemSummary.
        :type compartment_id: str

        :param availability_domain:
            The value to assign to the availability_domain property of this DbSystemSummary.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this DbSystemSummary.
        :type fault_domain: str

        :param endpoints:
            The value to assign to the endpoints property of this DbSystemSummary.
        :type endpoints: list[DbSystemEndpoint]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DbSystemSummary.
        :type lifecycle_state: str

        :param mysql_version:
            The value to assign to the mysql_version property of this DbSystemSummary.
        :type mysql_version: str

        :param time_created:
            The value to assign to the time_created property of this DbSystemSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DbSystemSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DbSystemSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DbSystemSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'availability_domain': 'str',
            'fault_domain': 'str',
            'endpoints': 'list[DbSystemEndpoint]',
            'lifecycle_state': 'str',
            'mysql_version': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain',
            'endpoints': 'endpoints',
            'lifecycle_state': 'lifecycleState',
            'mysql_version': 'mysqlVersion',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._availability_domain = None
        self._fault_domain = None
        self._endpoints = None
        self._lifecycle_state = None
        self._mysql_version = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DbSystemSummary.
        The OCID of the DB System.


        :return: The id of this DbSystemSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DbSystemSummary.
        The OCID of the DB System.


        :param id: The id of this DbSystemSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DbSystemSummary.
        The user-friendly name for the DB System. It does not have to be unique.


        :return: The display_name of this DbSystemSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DbSystemSummary.
        The user-friendly name for the DB System. It does not have to be unique.


        :param display_name: The display_name of this DbSystemSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this DbSystemSummary.
        User-provided data about the DB System.


        :return: The description of this DbSystemSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DbSystemSummary.
        User-provided data about the DB System.


        :param description: The description of this DbSystemSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DbSystemSummary.
        The OCID of the compartment the DB System belongs in.


        :return: The compartment_id of this DbSystemSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DbSystemSummary.
        The OCID of the compartment the DB System belongs in.


        :param compartment_id: The compartment_id of this DbSystemSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this DbSystemSummary.
        The Availability Domain where the primary DB System should be located.


        :return: The availability_domain of this DbSystemSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this DbSystemSummary.
        The Availability Domain where the primary DB System should be located.


        :param availability_domain: The availability_domain of this DbSystemSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this DbSystemSummary.
        The name of the Fault Domain the DB System is located in.


        :return: The fault_domain of this DbSystemSummary.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this DbSystemSummary.
        The name of the Fault Domain the DB System is located in.


        :param fault_domain: The fault_domain of this DbSystemSummary.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def endpoints(self):
        """
        Gets the endpoints of this DbSystemSummary.
        The network endpoints available for this DB System.


        :return: The endpoints of this DbSystemSummary.
        :rtype: list[DbSystemEndpoint]
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this DbSystemSummary.
        The network endpoints available for this DB System.


        :param endpoints: The endpoints of this DbSystemSummary.
        :type: list[DbSystemEndpoint]
        """
        self._endpoints = endpoints

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DbSystemSummary.
        The current state of the DB System.


        :return: The lifecycle_state of this DbSystemSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DbSystemSummary.
        The current state of the DB System.


        :param lifecycle_state: The lifecycle_state of this DbSystemSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def mysql_version(self):
        """
        **[Required]** Gets the mysql_version of this DbSystemSummary.
        Name of the MySQL Version in use for the DB System.


        :return: The mysql_version of this DbSystemSummary.
        :rtype: str
        """
        return self._mysql_version

    @mysql_version.setter
    def mysql_version(self, mysql_version):
        """
        Sets the mysql_version of this DbSystemSummary.
        Name of the MySQL Version in use for the DB System.


        :param mysql_version: The mysql_version of this DbSystemSummary.
        :type: str
        """
        self._mysql_version = mysql_version

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DbSystemSummary.
        The date and time the DB System was created.


        :return: The time_created of this DbSystemSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DbSystemSummary.
        The date and time the DB System was created.


        :param time_created: The time_created of this DbSystemSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this DbSystemSummary.
        The time the DB System was last updated.


        :return: The time_updated of this DbSystemSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DbSystemSummary.
        The time the DB System was last updated.


        :param time_updated: The time_updated of this DbSystemSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DbSystemSummary.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DbSystemSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DbSystemSummary.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DbSystemSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DbSystemSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DbSystemSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DbSystemSummary.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DbSystemSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsLabelView(object):
    """
    LogAnalyticsLabelView
    """

    #: A constant which can be used with the priority property of a LogAnalyticsLabelView.
    #: This constant has a value of "NONE"
    PRIORITY_NONE = "NONE"

    #: A constant which can be used with the priority property of a LogAnalyticsLabelView.
    #: This constant has a value of "LOW"
    PRIORITY_LOW = "LOW"

    #: A constant which can be used with the priority property of a LogAnalyticsLabelView.
    #: This constant has a value of "MEDIUM"
    PRIORITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the priority property of a LogAnalyticsLabelView.
    #: This constant has a value of "HIGH"
    PRIORITY_HIGH = "HIGH"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsLabelView object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param aliases:
            The value to assign to the aliases property of this LogAnalyticsLabelView.
        :type aliases: list[LogAnalyticsLabelAlias]

        :param count_usage_in_alert_rule:
            The value to assign to the count_usage_in_alert_rule property of this LogAnalyticsLabelView.
        :type count_usage_in_alert_rule: int

        :param count_usage_in_source:
            The value to assign to the count_usage_in_source property of this LogAnalyticsLabelView.
        :type count_usage_in_source: int

        :param id:
            The value to assign to the id property of this LogAnalyticsLabelView.
        :type id: object

        :param suggest_type:
            The value to assign to the suggest_type property of this LogAnalyticsLabelView.
        :type suggest_type: int

        :param description:
            The value to assign to the description property of this LogAnalyticsLabelView.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsLabelView.
        :type display_name: str

        :param edit_version:
            The value to assign to the edit_version property of this LogAnalyticsLabelView.
        :type edit_version: int

        :param impact:
            The value to assign to the impact property of this LogAnalyticsLabelView.
        :type impact: str

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsLabelView.
        :type is_system: bool

        :param name:
            The value to assign to the name property of this LogAnalyticsLabelView.
        :type name: str

        :param priority:
            The value to assign to the priority property of this LogAnalyticsLabelView.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type priority: str

        :param recommendation:
            The value to assign to the recommendation property of this LogAnalyticsLabelView.
        :type recommendation: str

        :param type:
            The value to assign to the type property of this LogAnalyticsLabelView.
        :type type: int

        :param is_user_deleted:
            The value to assign to the is_user_deleted property of this LogAnalyticsLabelView.
        :type is_user_deleted: bool

        """
        self.swagger_types = {
            'aliases': 'list[LogAnalyticsLabelAlias]',
            'count_usage_in_alert_rule': 'int',
            'count_usage_in_source': 'int',
            'id': 'object',
            'suggest_type': 'int',
            'description': 'str',
            'display_name': 'str',
            'edit_version': 'int',
            'impact': 'str',
            'is_system': 'bool',
            'name': 'str',
            'priority': 'str',
            'recommendation': 'str',
            'type': 'int',
            'is_user_deleted': 'bool'
        }

        self.attribute_map = {
            'aliases': 'aliases',
            'count_usage_in_alert_rule': 'countUsageInAlertRule',
            'count_usage_in_source': 'countUsageInSource',
            'id': 'id',
            'suggest_type': 'suggestType',
            'description': 'description',
            'display_name': 'displayName',
            'edit_version': 'editVersion',
            'impact': 'impact',
            'is_system': 'isSystem',
            'name': 'name',
            'priority': 'priority',
            'recommendation': 'recommendation',
            'type': 'type',
            'is_user_deleted': 'isUserDeleted'
        }

        self._aliases = None
        self._count_usage_in_alert_rule = None
        self._count_usage_in_source = None
        self._id = None
        self._suggest_type = None
        self._description = None
        self._display_name = None
        self._edit_version = None
        self._impact = None
        self._is_system = None
        self._name = None
        self._priority = None
        self._recommendation = None
        self._type = None
        self._is_user_deleted = None

    @property
    def aliases(self):
        """
        Gets the aliases of this LogAnalyticsLabelView.
        alias list


        :return: The aliases of this LogAnalyticsLabelView.
        :rtype: list[LogAnalyticsLabelAlias]
        """
        return self._aliases

    @aliases.setter
    def aliases(self, aliases):
        """
        Sets the aliases of this LogAnalyticsLabelView.
        alias list


        :param aliases: The aliases of this LogAnalyticsLabelView.
        :type: list[LogAnalyticsLabelAlias]
        """
        self._aliases = aliases

    @property
    def count_usage_in_alert_rule(self):
        """
        Gets the count_usage_in_alert_rule of this LogAnalyticsLabelView.
        alert rule usage count


        :return: The count_usage_in_alert_rule of this LogAnalyticsLabelView.
        :rtype: int
        """
        return self._count_usage_in_alert_rule

    @count_usage_in_alert_rule.setter
    def count_usage_in_alert_rule(self, count_usage_in_alert_rule):
        """
        Sets the count_usage_in_alert_rule of this LogAnalyticsLabelView.
        alert rule usage count


        :param count_usage_in_alert_rule: The count_usage_in_alert_rule of this LogAnalyticsLabelView.
        :type: int
        """
        self._count_usage_in_alert_rule = count_usage_in_alert_rule

    @property
    def count_usage_in_source(self):
        """
        Gets the count_usage_in_source of this LogAnalyticsLabelView.
        source usage count


        :return: The count_usage_in_source of this LogAnalyticsLabelView.
        :rtype: int
        """
        return self._count_usage_in_source

    @count_usage_in_source.setter
    def count_usage_in_source(self, count_usage_in_source):
        """
        Sets the count_usage_in_source of this LogAnalyticsLabelView.
        source usage count


        :param count_usage_in_source: The count_usage_in_source of this LogAnalyticsLabelView.
        :type: int
        """
        self._count_usage_in_source = count_usage_in_source

    @property
    def id(self):
        """
        Gets the id of this LogAnalyticsLabelView.
        id


        :return: The id of this LogAnalyticsLabelView.
        :rtype: object
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LogAnalyticsLabelView.
        id


        :param id: The id of this LogAnalyticsLabelView.
        :type: object
        """
        self._id = id

    @property
    def suggest_type(self):
        """
        Gets the suggest_type of this LogAnalyticsLabelView.
        suggest type


        :return: The suggest_type of this LogAnalyticsLabelView.
        :rtype: int
        """
        return self._suggest_type

    @suggest_type.setter
    def suggest_type(self, suggest_type):
        """
        Sets the suggest_type of this LogAnalyticsLabelView.
        suggest type


        :param suggest_type: The suggest_type of this LogAnalyticsLabelView.
        :type: int
        """
        self._suggest_type = suggest_type

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsLabelView.
        label description


        :return: The description of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsLabelView.
        label description


        :param description: The description of this LogAnalyticsLabelView.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsLabelView.
        label display name


        :return: The display_name of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsLabelView.
        label display name


        :param display_name: The display_name of this LogAnalyticsLabelView.
        :type: str
        """
        self._display_name = display_name

    @property
    def edit_version(self):
        """
        Gets the edit_version of this LogAnalyticsLabelView.
        tag edit version


        :return: The edit_version of this LogAnalyticsLabelView.
        :rtype: int
        """
        return self._edit_version

    @edit_version.setter
    def edit_version(self, edit_version):
        """
        Sets the edit_version of this LogAnalyticsLabelView.
        tag edit version


        :param edit_version: The edit_version of this LogAnalyticsLabelView.
        :type: int
        """
        self._edit_version = edit_version

    @property
    def impact(self):
        """
        Gets the impact of this LogAnalyticsLabelView.
        label impact


        :return: The impact of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """
        Sets the impact of this LogAnalyticsLabelView.
        label impact


        :param impact: The impact of this LogAnalyticsLabelView.
        :type: str
        """
        self._impact = impact

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsLabelView.
        is system flag


        :return: The is_system of this LogAnalyticsLabelView.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsLabelView.
        is system flag


        :param is_system: The is_system of this LogAnalyticsLabelView.
        :type: bool
        """
        self._is_system = is_system

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsLabelView.
        label name


        :return: The name of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsLabelView.
        label name


        :param name: The name of this LogAnalyticsLabelView.
        :type: str
        """
        self._name = name

    @property
    def priority(self):
        """
        Gets the priority of this LogAnalyticsLabelView.
        priority

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The priority of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this LogAnalyticsLabelView.
        priority


        :param priority: The priority of this LogAnalyticsLabelView.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH"]
        if not value_allowed_none_or_none_sentinel(priority, allowed_values):
            priority = 'UNKNOWN_ENUM_VALUE'
        self._priority = priority

    @property
    def recommendation(self):
        """
        Gets the recommendation of this LogAnalyticsLabelView.
        recommendation


        :return: The recommendation of this LogAnalyticsLabelView.
        :rtype: str
        """
        return self._recommendation

    @recommendation.setter
    def recommendation(self, recommendation):
        """
        Sets the recommendation of this LogAnalyticsLabelView.
        recommendation


        :param recommendation: The recommendation of this LogAnalyticsLabelView.
        :type: str
        """
        self._recommendation = recommendation

    @property
    def type(self):
        """
        Gets the type of this LogAnalyticsLabelView.
        type


        :return: The type of this LogAnalyticsLabelView.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogAnalyticsLabelView.
        type


        :param type: The type of this LogAnalyticsLabelView.
        :type: int
        """
        self._type = type

    @property
    def is_user_deleted(self):
        """
        Gets the is_user_deleted of this LogAnalyticsLabelView.
        user deleted flag


        :return: The is_user_deleted of this LogAnalyticsLabelView.
        :rtype: bool
        """
        return self._is_user_deleted

    @is_user_deleted.setter
    def is_user_deleted(self, is_user_deleted):
        """
        Sets the is_user_deleted of this LogAnalyticsLabelView.
        user deleted flag


        :param is_user_deleted: The is_user_deleted of this LogAnalyticsLabelView.
        :type: bool
        """
        self._is_user_deleted = is_user_deleted

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateServiceGatewayDetails(object):
    """
    CreateServiceGatewayDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateServiceGatewayDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateServiceGatewayDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateServiceGatewayDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateServiceGatewayDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateServiceGatewayDetails.
        :type freeform_tags: dict(str, str)

        :param route_table_id:
            The value to assign to the route_table_id property of this CreateServiceGatewayDetails.
        :type route_table_id: str

        :param services:
            The value to assign to the services property of this CreateServiceGatewayDetails.
        :type services: list[ServiceIdRequestDetails]

        :param vcn_id:
            The value to assign to the vcn_id property of this CreateServiceGatewayDetails.
        :type vcn_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'route_table_id': 'str',
            'services': 'list[ServiceIdRequestDetails]',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'route_table_id': 'routeTableId',
            'services': 'services',
            'vcn_id': 'vcnId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._route_table_id = None
        self._services = None
        self._vcn_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateServiceGatewayDetails.
        The `OCID]`__ of the compartment to contain the service gateway.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateServiceGatewayDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateServiceGatewayDetails.
        The `OCID]`__ of the compartment to contain the service gateway.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateServiceGatewayDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateServiceGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateServiceGatewayDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateServiceGatewayDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateServiceGatewayDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateServiceGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateServiceGatewayDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateServiceGatewayDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateServiceGatewayDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateServiceGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateServiceGatewayDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateServiceGatewayDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateServiceGatewayDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this CreateServiceGatewayDetails.
        The OCID of the route table the service gateway will use.

        If you don't specify a route table here, the service gateway is created without an associated route
        table. The Networking service does NOT automatically associate the attached VCN's default route table
        with the service gateway.

        For information about why you would associate a route table with a service gateway, see
        `Transit Routing: Private Access to Oracle Services`__.

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this CreateServiceGatewayDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this CreateServiceGatewayDetails.
        The OCID of the route table the service gateway will use.

        If you don't specify a route table here, the service gateway is created without an associated route
        table. The Networking service does NOT automatically associate the attached VCN's default route table
        with the service gateway.

        For information about why you would associate a route table with a service gateway, see
        `Transit Routing: Private Access to Oracle Services`__.

        __ https://docs.cloud.oracle.com/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this CreateServiceGatewayDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def services(self):
        """
        **[Required]** Gets the services of this CreateServiceGatewayDetails.
        List of the OCIDs of the :class:`Service` objects to
        enable for the service gateway. This list can be empty if you don't want to enable any
        `Service` objects when you create the gateway. You can enable a `Service`
        object later by using either :func:`attach_service_id`
        or :func:`update_service_gateway`.

        For each enabled `Service`, make sure there's a route rule with the `Service` object's `cidrBlock`
        as the rule's destination and the service gateway as the rule's target. See
        :class:`RouteTable`.


        :return: The services of this CreateServiceGatewayDetails.
        :rtype: list[ServiceIdRequestDetails]
        """
        return self._services

    @services.setter
    def services(self, services):
        """
        Sets the services of this CreateServiceGatewayDetails.
        List of the OCIDs of the :class:`Service` objects to
        enable for the service gateway. This list can be empty if you don't want to enable any
        `Service` objects when you create the gateway. You can enable a `Service`
        object later by using either :func:`attach_service_id`
        or :func:`update_service_gateway`.

        For each enabled `Service`, make sure there's a route rule with the `Service` object's `cidrBlock`
        as the rule's destination and the service gateway as the rule's target. See
        :class:`RouteTable`.


        :param services: The services of this CreateServiceGatewayDetails.
        :type: list[ServiceIdRequestDetails]
        """
        self._services = services

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this CreateServiceGatewayDetails.
        The `OCID`__ of the VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this CreateServiceGatewayDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this CreateServiceGatewayDetails.
        The `OCID`__ of the VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this CreateServiceGatewayDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTagDefaultDetails(object):
    """
    CreateTagDefaultDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTagDefaultDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateTagDefaultDetails.
        :type compartment_id: str

        :param tag_definition_id:
            The value to assign to the tag_definition_id property of this CreateTagDefaultDetails.
        :type tag_definition_id: str

        :param value:
            The value to assign to the value property of this CreateTagDefaultDetails.
        :type value: str

        :param is_required:
            The value to assign to the is_required property of this CreateTagDefaultDetails.
        :type is_required: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'tag_definition_id': 'str',
            'value': 'str',
            'is_required': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'tag_definition_id': 'tagDefinitionId',
            'value': 'value',
            'is_required': 'isRequired'
        }

        self._compartment_id = None
        self._tag_definition_id = None
        self._value = None
        self._is_required = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateTagDefaultDetails.
        The OCID of the compartment. The tag default will be applied to all new resources created in this compartment.


        :return: The compartment_id of this CreateTagDefaultDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateTagDefaultDetails.
        The OCID of the compartment. The tag default will be applied to all new resources created in this compartment.


        :param compartment_id: The compartment_id of this CreateTagDefaultDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def tag_definition_id(self):
        """
        **[Required]** Gets the tag_definition_id of this CreateTagDefaultDetails.
        The OCID of the tag definition. The tag default will always assign a default value for this tag definition.


        :return: The tag_definition_id of this CreateTagDefaultDetails.
        :rtype: str
        """
        return self._tag_definition_id

    @tag_definition_id.setter
    def tag_definition_id(self, tag_definition_id):
        """
        Sets the tag_definition_id of this CreateTagDefaultDetails.
        The OCID of the tag definition. The tag default will always assign a default value for this tag definition.


        :param tag_definition_id: The tag_definition_id of this CreateTagDefaultDetails.
        :type: str
        """
        self._tag_definition_id = tag_definition_id

    @property
    def value(self):
        """
        **[Required]** Gets the value of this CreateTagDefaultDetails.
        The default value for the tag definition. This will be applied to all new resources created in the compartment.


        :return: The value of this CreateTagDefaultDetails.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this CreateTagDefaultDetails.
        The default value for the tag definition. This will be applied to all new resources created in the compartment.


        :param value: The value of this CreateTagDefaultDetails.
        :type: str
        """
        self._value = value

    @property
    def is_required(self):
        """
        Gets the is_required of this CreateTagDefaultDetails.
        If you specify that a value is required, a value is set during resource creation (either by
        the user creating the resource or another tag defualt). If no value is set, resource
        creation is blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :return: The is_required of this CreateTagDefaultDetails.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this CreateTagDefaultDetails.
        If you specify that a value is required, a value is set during resource creation (either by
        the user creating the resource or another tag defualt). If no value is set, resource
        creation is blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :param is_required: The is_required of this CreateTagDefaultDetails.
        :type: bool
        """
        self._is_required = is_required

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .backup import Backup
from .backup_policy import BackupPolicy
from .backup_summary import BackupSummary
from .configuration import Configuration
from .configuration_summary import ConfigurationSummary
from .configuration_variables import ConfigurationVariables
from .create_backup_details import CreateBackupDetails
from .create_backup_policy_details import CreateBackupPolicyDetails
from .create_configuration_details import CreateConfigurationDetails
from .create_db_system_details import CreateDbSystemDetails
from .create_db_system_source_details import CreateDbSystemSourceDetails
from .create_db_system_source_from_backup_details import CreateDbSystemSourceFromBackupDetails
from .create_db_system_source_import_from_url_details import CreateDbSystemSourceImportFromUrlDetails
from .create_maintenance_details import CreateMaintenanceDetails
from .db_system import DbSystem
from .db_system_endpoint import DbSystemEndpoint
from .db_system_source import DbSystemSource
from .db_system_source_from_backup import DbSystemSourceFromBackup
from .db_system_source_import_from_url import DbSystemSourceImportFromUrl
from .db_system_summary import DbSystemSummary
from .maintenance_details import MaintenanceDetails
from .restart_db_system_details import RestartDbSystemDetails
from .shape_summary import ShapeSummary
from .stop_db_system_details import StopDbSystemDetails
from .update_backup_details import UpdateBackupDetails
from .update_backup_policy_details import UpdateBackupPolicyDetails
from .update_configuration_details import UpdateConfigurationDetails
from .update_db_system_details import UpdateDbSystemDetails
from .update_maintenance_details import UpdateMaintenanceDetails
from .version import Version
from .version_summary import VersionSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for mysql services.
mysql_type_mapping = {
    "Backup": Backup,
    "BackupPolicy": BackupPolicy,
    "BackupSummary": BackupSummary,
    "Configuration": Configuration,
    "ConfigurationSummary": ConfigurationSummary,
    "ConfigurationVariables": ConfigurationVariables,
    "CreateBackupDetails": CreateBackupDetails,
    "CreateBackupPolicyDetails": CreateBackupPolicyDetails,
    "CreateConfigurationDetails": CreateConfigurationDetails,
    "CreateDbSystemDetails": CreateDbSystemDetails,
    "CreateDbSystemSourceDetails": CreateDbSystemSourceDetails,
    "CreateDbSystemSourceFromBackupDetails": CreateDbSystemSourceFromBackupDetails,
    "CreateDbSystemSourceImportFromUrlDetails": CreateDbSystemSourceImportFromUrlDetails,
    "CreateMaintenanceDetails": CreateMaintenanceDetails,
    "DbSystem": DbSystem,
    "DbSystemEndpoint": DbSystemEndpoint,
    "DbSystemSource": DbSystemSource,
    "DbSystemSourceFromBackup": DbSystemSourceFromBackup,
    "DbSystemSourceImportFromUrl": DbSystemSourceImportFromUrl,
    "DbSystemSummary": DbSystemSummary,
    "MaintenanceDetails": MaintenanceDetails,
    "RestartDbSystemDetails": RestartDbSystemDetails,
    "ShapeSummary": ShapeSummary,
    "StopDbSystemDetails": StopDbSystemDetails,
    "UpdateBackupDetails": UpdateBackupDetails,
    "UpdateBackupPolicyDetails": UpdateBackupPolicyDetails,
    "UpdateConfigurationDetails": UpdateConfigurationDetails,
    "UpdateDbSystemDetails": UpdateDbSystemDetails,
    "UpdateMaintenanceDetails": UpdateMaintenanceDetails,
    "Version": Version,
    "VersionSummary": VersionSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .appliance_export_job import ApplianceExportJob
from .appliance_export_job_summary import ApplianceExportJobSummary
from .attach_devices_details import AttachDevicesDetails
from .change_appliance_export_job_compartment_details import ChangeApplianceExportJobCompartmentDetails
from .change_transfer_job_compartment_details import ChangeTransferJobCompartmentDetails
from .create_appliance_export_job_details import CreateApplianceExportJobDetails
from .create_transfer_appliance_details import CreateTransferApplianceDetails
from .create_transfer_appliance_entitlement_details import CreateTransferApplianceEntitlementDetails
from .create_transfer_device_details import CreateTransferDeviceDetails
from .create_transfer_job_details import CreateTransferJobDetails
from .create_transfer_package_details import CreateTransferPackageDetails
from .detach_devices_details import DetachDevicesDetails
from .multiple_transfer_appliances import MultipleTransferAppliances
from .multiple_transfer_devices import MultipleTransferDevices
from .multiple_transfer_packages import MultipleTransferPackages
from .new_transfer_device import NewTransferDevice
from .shipping_address import ShippingAddress
from .shipping_vendors import ShippingVendors
from .transfer_appliance import TransferAppliance
from .transfer_appliance_certificate import TransferApplianceCertificate
from .transfer_appliance_encryption_passphrase import TransferApplianceEncryptionPassphrase
from .transfer_appliance_entitlement import TransferApplianceEntitlement
from .transfer_appliance_entitlement_summary import TransferApplianceEntitlementSummary
from .transfer_appliance_public_key import TransferAppliancePublicKey
from .transfer_appliance_summary import TransferApplianceSummary
from .transfer_device import TransferDevice
from .transfer_device_summary import TransferDeviceSummary
from .transfer_job import TransferJob
from .transfer_job_summary import TransferJobSummary
from .transfer_package import TransferPackage
from .transfer_package_summary import TransferPackageSummary
from .update_appliance_export_job_details import UpdateApplianceExportJobDetails
from .update_transfer_appliance_details import UpdateTransferApplianceDetails
from .update_transfer_device_details import UpdateTransferDeviceDetails
from .update_transfer_job_details import UpdateTransferJobDetails
from .update_transfer_package_details import UpdateTransferPackageDetails

# Maps type names to classes for dts services.
dts_type_mapping = {
    "ApplianceExportJob": ApplianceExportJob,
    "ApplianceExportJobSummary": ApplianceExportJobSummary,
    "AttachDevicesDetails": AttachDevicesDetails,
    "ChangeApplianceExportJobCompartmentDetails": ChangeApplianceExportJobCompartmentDetails,
    "ChangeTransferJobCompartmentDetails": ChangeTransferJobCompartmentDetails,
    "CreateApplianceExportJobDetails": CreateApplianceExportJobDetails,
    "CreateTransferApplianceDetails": CreateTransferApplianceDetails,
    "CreateTransferApplianceEntitlementDetails": CreateTransferApplianceEntitlementDetails,
    "CreateTransferDeviceDetails": CreateTransferDeviceDetails,
    "CreateTransferJobDetails": CreateTransferJobDetails,
    "CreateTransferPackageDetails": CreateTransferPackageDetails,
    "DetachDevicesDetails": DetachDevicesDetails,
    "MultipleTransferAppliances": MultipleTransferAppliances,
    "MultipleTransferDevices": MultipleTransferDevices,
    "MultipleTransferPackages": MultipleTransferPackages,
    "NewTransferDevice": NewTransferDevice,
    "ShippingAddress": ShippingAddress,
    "ShippingVendors": ShippingVendors,
    "TransferAppliance": TransferAppliance,
    "TransferApplianceCertificate": TransferApplianceCertificate,
    "TransferApplianceEncryptionPassphrase": TransferApplianceEncryptionPassphrase,
    "TransferApplianceEntitlement": TransferApplianceEntitlement,
    "TransferApplianceEntitlementSummary": TransferApplianceEntitlementSummary,
    "TransferAppliancePublicKey": TransferAppliancePublicKey,
    "TransferApplianceSummary": TransferApplianceSummary,
    "TransferDevice": TransferDevice,
    "TransferDeviceSummary": TransferDeviceSummary,
    "TransferJob": TransferJob,
    "TransferJobSummary": TransferJobSummary,
    "TransferPackage": TransferPackage,
    "TransferPackageSummary": TransferPackageSummary,
    "UpdateApplianceExportJobDetails": UpdateApplianceExportJobDetails,
    "UpdateTransferApplianceDetails": UpdateTransferApplianceDetails,
    "UpdateTransferDeviceDetails": UpdateTransferDeviceDetails,
    "UpdateTransferJobDetails": UpdateTransferJobDetails,
    "UpdateTransferPackageDetails": UpdateTransferPackageDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIPSecConnectionTunnelDetails(object):
    """
    CreateIPSecConnectionTunnelDetails model.
    """

    #: A constant which can be used with the routing property of a CreateIPSecConnectionTunnelDetails.
    #: This constant has a value of "BGP"
    ROUTING_BGP = "BGP"

    #: A constant which can be used with the routing property of a CreateIPSecConnectionTunnelDetails.
    #: This constant has a value of "STATIC"
    ROUTING_STATIC = "STATIC"

    #: A constant which can be used with the ike_version property of a CreateIPSecConnectionTunnelDetails.
    #: This constant has a value of "V1"
    IKE_VERSION_V1 = "V1"

    #: A constant which can be used with the ike_version property of a CreateIPSecConnectionTunnelDetails.
    #: This constant has a value of "V2"
    IKE_VERSION_V2 = "V2"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIPSecConnectionTunnelDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateIPSecConnectionTunnelDetails.
        :type display_name: str

        :param routing:
            The value to assign to the routing property of this CreateIPSecConnectionTunnelDetails.
            Allowed values for this property are: "BGP", "STATIC"
        :type routing: str

        :param ike_version:
            The value to assign to the ike_version property of this CreateIPSecConnectionTunnelDetails.
            Allowed values for this property are: "V1", "V2"
        :type ike_version: str

        :param shared_secret:
            The value to assign to the shared_secret property of this CreateIPSecConnectionTunnelDetails.
        :type shared_secret: str

        :param bgp_session_config:
            The value to assign to the bgp_session_config property of this CreateIPSecConnectionTunnelDetails.
        :type bgp_session_config: CreateIPSecTunnelBgpSessionDetails

        """
        self.swagger_types = {
            'display_name': 'str',
            'routing': 'str',
            'ike_version': 'str',
            'shared_secret': 'str',
            'bgp_session_config': 'CreateIPSecTunnelBgpSessionDetails'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'routing': 'routing',
            'ike_version': 'ikeVersion',
            'shared_secret': 'sharedSecret',
            'bgp_session_config': 'bgpSessionConfig'
        }

        self._display_name = None
        self._routing = None
        self._ike_version = None
        self._shared_secret = None
        self._bgp_session_config = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateIPSecConnectionTunnelDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this CreateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateIPSecConnectionTunnelDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this CreateIPSecConnectionTunnelDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def routing(self):
        """
        Gets the routing of this CreateIPSecConnectionTunnelDetails.
        The type of routing to use for this tunnel (either BGP dynamic routing or static routing).

        Allowed values for this property are: "BGP", "STATIC"


        :return: The routing of this CreateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._routing

    @routing.setter
    def routing(self, routing):
        """
        Sets the routing of this CreateIPSecConnectionTunnelDetails.
        The type of routing to use for this tunnel (either BGP dynamic routing or static routing).


        :param routing: The routing of this CreateIPSecConnectionTunnelDetails.
        :type: str
        """
        allowed_values = ["BGP", "STATIC"]
        if not value_allowed_none_or_none_sentinel(routing, allowed_values):
            raise ValueError(
                "Invalid value for `routing`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._routing = routing

    @property
    def ike_version(self):
        """
        Gets the ike_version of this CreateIPSecConnectionTunnelDetails.
        Internet Key Exchange protocol version.

        Allowed values for this property are: "V1", "V2"


        :return: The ike_version of this CreateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._ike_version

    @ike_version.setter
    def ike_version(self, ike_version):
        """
        Sets the ike_version of this CreateIPSecConnectionTunnelDetails.
        Internet Key Exchange protocol version.


        :param ike_version: The ike_version of this CreateIPSecConnectionTunnelDetails.
        :type: str
        """
        allowed_values = ["V1", "V2"]
        if not value_allowed_none_or_none_sentinel(ike_version, allowed_values):
            raise ValueError(
                "Invalid value for `ike_version`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._ike_version = ike_version

    @property
    def shared_secret(self):
        """
        Gets the shared_secret of this CreateIPSecConnectionTunnelDetails.
        The shared secret (pre-shared key) to use for the IPSec tunnel. Only numbers, letters, and
        spaces are allowed. If you don't provide a value,
        Oracle generates a value for you. You can specify your own shared secret later if
        you like with :func:`update_ip_sec_connection_tunnel_shared_secret`.


        :return: The shared_secret of this CreateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._shared_secret

    @shared_secret.setter
    def shared_secret(self, shared_secret):
        """
        Sets the shared_secret of this CreateIPSecConnectionTunnelDetails.
        The shared secret (pre-shared key) to use for the IPSec tunnel. Only numbers, letters, and
        spaces are allowed. If you don't provide a value,
        Oracle generates a value for you. You can specify your own shared secret later if
        you like with :func:`update_ip_sec_connection_tunnel_shared_secret`.


        :param shared_secret: The shared_secret of this CreateIPSecConnectionTunnelDetails.
        :type: str
        """
        self._shared_secret = shared_secret

    @property
    def bgp_session_config(self):
        """
        Gets the bgp_session_config of this CreateIPSecConnectionTunnelDetails.
        Information for establishing a BGP session for the IPSec tunnel. Required if the tunnel uses
        BGP dynamic routing.

        If the tunnel instead uses static routing, you may optionally provide
        this object and set an IP address for one or both ends of the IPSec tunnel for the purposes
        of troubleshooting or monitoring the tunnel.


        :return: The bgp_session_config of this CreateIPSecConnectionTunnelDetails.
        :rtype: CreateIPSecTunnelBgpSessionDetails
        """
        return self._bgp_session_config

    @bgp_session_config.setter
    def bgp_session_config(self, bgp_session_config):
        """
        Sets the bgp_session_config of this CreateIPSecConnectionTunnelDetails.
        Information for establishing a BGP session for the IPSec tunnel. Required if the tunnel uses
        BGP dynamic routing.

        If the tunnel instead uses static routing, you may optionally provide
        this object and set an IP address for one or both ends of the IPSec tunnel for the purposes
        of troubleshooting or monitoring the tunnel.


        :param bgp_session_config: The bgp_session_config of this CreateIPSecConnectionTunnelDetails.
        :type: CreateIPSecTunnelBgpSessionDetails
        """
        self._bgp_session_config = bgp_session_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_data_asset_details import CreateDataAssetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataAssetFromObjectStorage(CreateDataAssetDetails):
    """
    The Object Storage data asset details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataAssetFromObjectStorage object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CreateDataAssetFromObjectStorage.model_type` attribute
        of this class is ``ORACLE_OBJECT_STORAGE_DATA_ASSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateDataAssetFromObjectStorage.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateDataAssetFromObjectStorage.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateDataAssetFromObjectStorage.
        :type model_version: str

        :param name:
            The value to assign to the name property of this CreateDataAssetFromObjectStorage.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateDataAssetFromObjectStorage.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateDataAssetFromObjectStorage.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateDataAssetFromObjectStorage.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this CreateDataAssetFromObjectStorage.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this CreateDataAssetFromObjectStorage.
        :type asset_properties: dict(str, str)

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateDataAssetFromObjectStorage.
        :type registry_metadata: RegistryMetadata

        :param url:
            The value to assign to the url property of this CreateDataAssetFromObjectStorage.
        :type url: str

        :param tenancy_id:
            The value to assign to the tenancy_id property of this CreateDataAssetFromObjectStorage.
        :type tenancy_id: str

        :param namespace:
            The value to assign to the namespace property of this CreateDataAssetFromObjectStorage.
        :type namespace: str

        :param default_connection:
            The value to assign to the default_connection property of this CreateDataAssetFromObjectStorage.
        :type default_connection: CreateConnectionFromObjectStorage

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'registry_metadata': 'RegistryMetadata',
            'url': 'str',
            'tenancy_id': 'str',
            'namespace': 'str',
            'default_connection': 'CreateConnectionFromObjectStorage'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'registry_metadata': 'registryMetadata',
            'url': 'url',
            'tenancy_id': 'tenancyId',
            'namespace': 'namespace',
            'default_connection': 'defaultConnection'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._registry_metadata = None
        self._url = None
        self._tenancy_id = None
        self._namespace = None
        self._default_connection = None
        self._model_type = 'ORACLE_OBJECT_STORAGE_DATA_ASSET'

    @property
    def url(self):
        """
        Gets the url of this CreateDataAssetFromObjectStorage.
        url


        :return: The url of this CreateDataAssetFromObjectStorage.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this CreateDataAssetFromObjectStorage.
        url


        :param url: The url of this CreateDataAssetFromObjectStorage.
        :type: str
        """
        self._url = url

    @property
    def tenancy_id(self):
        """
        Gets the tenancy_id of this CreateDataAssetFromObjectStorage.
        The OCI tenancy OCID.


        :return: The tenancy_id of this CreateDataAssetFromObjectStorage.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this CreateDataAssetFromObjectStorage.
        The OCI tenancy OCID.


        :param tenancy_id: The tenancy_id of this CreateDataAssetFromObjectStorage.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def namespace(self):
        """
        Gets the namespace of this CreateDataAssetFromObjectStorage.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The namespace of this CreateDataAssetFromObjectStorage.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this CreateDataAssetFromObjectStorage.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param namespace: The namespace of this CreateDataAssetFromObjectStorage.
        :type: str
        """
        self._namespace = namespace

    @property
    def default_connection(self):
        """
        Gets the default_connection of this CreateDataAssetFromObjectStorage.

        :return: The default_connection of this CreateDataAssetFromObjectStorage.
        :rtype: CreateConnectionFromObjectStorage
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this CreateDataAssetFromObjectStorage.

        :param default_connection: The default_connection of this CreateDataAssetFromObjectStorage.
        :type: CreateConnectionFromObjectStorage
        """
        self._default_connection = default_connection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstancePoolInstanceLoadBalancerBackend(object):
    """
    Represents the load balancer Backend that is configured for an instance pool instance.
    """

    #: A constant which can be used with the backend_health_status property of a InstancePoolInstanceLoadBalancerBackend.
    #: This constant has a value of "OK"
    BACKEND_HEALTH_STATUS_OK = "OK"

    #: A constant which can be used with the backend_health_status property of a InstancePoolInstanceLoadBalancerBackend.
    #: This constant has a value of "WARNING"
    BACKEND_HEALTH_STATUS_WARNING = "WARNING"

    #: A constant which can be used with the backend_health_status property of a InstancePoolInstanceLoadBalancerBackend.
    #: This constant has a value of "CRITICAL"
    BACKEND_HEALTH_STATUS_CRITICAL = "CRITICAL"

    #: A constant which can be used with the backend_health_status property of a InstancePoolInstanceLoadBalancerBackend.
    #: This constant has a value of "UNKNOWN"
    BACKEND_HEALTH_STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new InstancePoolInstanceLoadBalancerBackend object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param load_balancer_id:
            The value to assign to the load_balancer_id property of this InstancePoolInstanceLoadBalancerBackend.
        :type load_balancer_id: str

        :param backend_set_name:
            The value to assign to the backend_set_name property of this InstancePoolInstanceLoadBalancerBackend.
        :type backend_set_name: str

        :param backend_name:
            The value to assign to the backend_name property of this InstancePoolInstanceLoadBalancerBackend.
        :type backend_name: str

        :param backend_health_status:
            The value to assign to the backend_health_status property of this InstancePoolInstanceLoadBalancerBackend.
            Allowed values for this property are: "OK", "WARNING", "CRITICAL", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type backend_health_status: str

        """
        self.swagger_types = {
            'load_balancer_id': 'str',
            'backend_set_name': 'str',
            'backend_name': 'str',
            'backend_health_status': 'str'
        }

        self.attribute_map = {
            'load_balancer_id': 'loadBalancerId',
            'backend_set_name': 'backendSetName',
            'backend_name': 'backendName',
            'backend_health_status': 'backendHealthStatus'
        }

        self._load_balancer_id = None
        self._backend_set_name = None
        self._backend_name = None
        self._backend_health_status = None

    @property
    def load_balancer_id(self):
        """
        **[Required]** Gets the load_balancer_id of this InstancePoolInstanceLoadBalancerBackend.
        The OCID of the load balancer attached to the instance pool.


        :return: The load_balancer_id of this InstancePoolInstanceLoadBalancerBackend.
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """
        Sets the load_balancer_id of this InstancePoolInstanceLoadBalancerBackend.
        The OCID of the load balancer attached to the instance pool.


        :param load_balancer_id: The load_balancer_id of this InstancePoolInstanceLoadBalancerBackend.
        :type: str
        """
        self._load_balancer_id = load_balancer_id

    @property
    def backend_set_name(self):
        """
        **[Required]** Gets the backend_set_name of this InstancePoolInstanceLoadBalancerBackend.
        The name of the backend set on the load balancer.


        :return: The backend_set_name of this InstancePoolInstanceLoadBalancerBackend.
        :rtype: str
        """
        return self._backend_set_name

    @backend_set_name.setter
    def backend_set_name(self, backend_set_name):
        """
        Sets the backend_set_name of this InstancePoolInstanceLoadBalancerBackend.
        The name of the backend set on the load balancer.


        :param backend_set_name: The backend_set_name of this InstancePoolInstanceLoadBalancerBackend.
        :type: str
        """
        self._backend_set_name = backend_set_name

    @property
    def backend_name(self):
        """
        **[Required]** Gets the backend_name of this InstancePoolInstanceLoadBalancerBackend.
        The name of the backend in the backend set.


        :return: The backend_name of this InstancePoolInstanceLoadBalancerBackend.
        :rtype: str
        """
        return self._backend_name

    @backend_name.setter
    def backend_name(self, backend_name):
        """
        Sets the backend_name of this InstancePoolInstanceLoadBalancerBackend.
        The name of the backend in the backend set.


        :param backend_name: The backend_name of this InstancePoolInstanceLoadBalancerBackend.
        :type: str
        """
        self._backend_name = backend_name

    @property
    def backend_health_status(self):
        """
        **[Required]** Gets the backend_health_status of this InstancePoolInstanceLoadBalancerBackend.
        The health of the backend as observed by the load balancer.

        Allowed values for this property are: "OK", "WARNING", "CRITICAL", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The backend_health_status of this InstancePoolInstanceLoadBalancerBackend.
        :rtype: str
        """
        return self._backend_health_status

    @backend_health_status.setter
    def backend_health_status(self, backend_health_status):
        """
        Sets the backend_health_status of this InstancePoolInstanceLoadBalancerBackend.
        The health of the backend as observed by the load balancer.


        :param backend_health_status: The backend_health_status of this InstancePoolInstanceLoadBalancerBackend.
        :type: str
        """
        allowed_values = ["OK", "WARNING", "CRITICAL", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(backend_health_status, allowed_values):
            backend_health_status = 'UNKNOWN_ENUM_VALUE'
        self._backend_health_status = backend_health_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .image_capability_schema_descriptor import ImageCapabilitySchemaDescriptor
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BooleanImageCapabilitySchemaDescriptor(ImageCapabilitySchemaDescriptor):
    """
    Boolean type ImageCapabilitySchemaDescriptor
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BooleanImageCapabilitySchemaDescriptor object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.BooleanImageCapabilitySchemaDescriptor.descriptor_type` attribute
        of this class is ``boolean`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param descriptor_type:
            The value to assign to the descriptor_type property of this BooleanImageCapabilitySchemaDescriptor.
        :type descriptor_type: str

        :param source:
            The value to assign to the source property of this BooleanImageCapabilitySchemaDescriptor.
            Allowed values for this property are: "GLOBAL", "IMAGE"
        :type source: str

        :param default_value:
            The value to assign to the default_value property of this BooleanImageCapabilitySchemaDescriptor.
        :type default_value: bool

        """
        self.swagger_types = {
            'descriptor_type': 'str',
            'source': 'str',
            'default_value': 'bool'
        }

        self.attribute_map = {
            'descriptor_type': 'descriptorType',
            'source': 'source',
            'default_value': 'defaultValue'
        }

        self._descriptor_type = None
        self._source = None
        self._default_value = None
        self._descriptor_type = 'boolean'

    @property
    def default_value(self):
        """
        Gets the default_value of this BooleanImageCapabilitySchemaDescriptor.
        the default value


        :return: The default_value of this BooleanImageCapabilitySchemaDescriptor.
        :rtype: bool
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this BooleanImageCapabilitySchemaDescriptor.
        the default value


        :param default_value: The default_value of this BooleanImageCapabilitySchemaDescriptor.
        :type: bool
        """
        self._default_value = default_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAcceptedAgreementDetails(object):
    """
    The model for the parameters needed to accept a terms of use agreement.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAcceptedAgreementDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAcceptedAgreementDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAcceptedAgreementDetails.
        :type compartment_id: str

        :param listing_id:
            The value to assign to the listing_id property of this CreateAcceptedAgreementDetails.
        :type listing_id: str

        :param package_version:
            The value to assign to the package_version property of this CreateAcceptedAgreementDetails.
        :type package_version: str

        :param agreement_id:
            The value to assign to the agreement_id property of this CreateAcceptedAgreementDetails.
        :type agreement_id: str

        :param signature:
            The value to assign to the signature property of this CreateAcceptedAgreementDetails.
        :type signature: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAcceptedAgreementDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAcceptedAgreementDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'listing_id': 'str',
            'package_version': 'str',
            'agreement_id': 'str',
            'signature': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'listing_id': 'listingId',
            'package_version': 'packageVersion',
            'agreement_id': 'agreementId',
            'signature': 'signature',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._listing_id = None
        self._package_version = None
        self._agreement_id = None
        self._signature = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateAcceptedAgreementDetails.
        A display name for the accepted agreement.


        :return: The display_name of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAcceptedAgreementDetails.
        A display name for the accepted agreement.


        :param display_name: The display_name of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateAcceptedAgreementDetails.
        The unique identifier for the compartment where the agreement will be accepted.


        :return: The compartment_id of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAcceptedAgreementDetails.
        The unique identifier for the compartment where the agreement will be accepted.


        :param compartment_id: The compartment_id of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def listing_id(self):
        """
        **[Required]** Gets the listing_id of this CreateAcceptedAgreementDetails.
        The unique identifier for the listing associated with the agreement.


        :return: The listing_id of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this CreateAcceptedAgreementDetails.
        The unique identifier for the listing associated with the agreement.


        :param listing_id: The listing_id of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def package_version(self):
        """
        **[Required]** Gets the package_version of this CreateAcceptedAgreementDetails.
        The package version associated with the agreement.


        :return: The package_version of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._package_version

    @package_version.setter
    def package_version(self, package_version):
        """
        Sets the package_version of this CreateAcceptedAgreementDetails.
        The package version associated with the agreement.


        :param package_version: The package_version of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._package_version = package_version

    @property
    def agreement_id(self):
        """
        **[Required]** Gets the agreement_id of this CreateAcceptedAgreementDetails.
        The agreement to accept.


        :return: The agreement_id of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, agreement_id):
        """
        Sets the agreement_id of this CreateAcceptedAgreementDetails.
        The agreement to accept.


        :param agreement_id: The agreement_id of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._agreement_id = agreement_id

    @property
    def signature(self):
        """
        **[Required]** Gets the signature of this CreateAcceptedAgreementDetails.
        A signature generated for the listing package agreements that you can retrieve
        with `GetAgreement`__.

        __ https://docs.cloud.oracle.com/api/#/en/marketplace/20181001/Agreement/GetAgreement


        :return: The signature of this CreateAcceptedAgreementDetails.
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this CreateAcceptedAgreementDetails.
        A signature generated for the listing package agreements that you can retrieve
        with `GetAgreement`__.

        __ https://docs.cloud.oracle.com/api/#/en/marketplace/20181001/Agreement/GetAgreement


        :param signature: The signature of this CreateAcceptedAgreementDetails.
        :type: str
        """
        self._signature = signature

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAcceptedAgreementDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateAcceptedAgreementDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAcceptedAgreementDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateAcceptedAgreementDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAcceptedAgreementDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateAcceptedAgreementDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAcceptedAgreementDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateAcceptedAgreementDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CopyVolumeBackupDetails(object):
    """
    CopyVolumeBackupDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CopyVolumeBackupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination_region:
            The value to assign to the destination_region property of this CopyVolumeBackupDetails.
        :type destination_region: str

        :param display_name:
            The value to assign to the display_name property of this CopyVolumeBackupDetails.
        :type display_name: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CopyVolumeBackupDetails.
        :type kms_key_id: str

        """
        self.swagger_types = {
            'destination_region': 'str',
            'display_name': 'str',
            'kms_key_id': 'str'
        }

        self.attribute_map = {
            'destination_region': 'destinationRegion',
            'display_name': 'displayName',
            'kms_key_id': 'kmsKeyId'
        }

        self._destination_region = None
        self._display_name = None
        self._kms_key_id = None

    @property
    def destination_region(self):
        """
        **[Required]** Gets the destination_region of this CopyVolumeBackupDetails.
        The name of the destination region.

        Example: `us-ashburn-1`


        :return: The destination_region of this CopyVolumeBackupDetails.
        :rtype: str
        """
        return self._destination_region

    @destination_region.setter
    def destination_region(self, destination_region):
        """
        Sets the destination_region of this CopyVolumeBackupDetails.
        The name of the destination region.

        Example: `us-ashburn-1`


        :param destination_region: The destination_region of this CopyVolumeBackupDetails.
        :type: str
        """
        self._destination_region = destination_region

    @property
    def display_name(self):
        """
        Gets the display_name of this CopyVolumeBackupDetails.
        A user-friendly name for the volume backup. Does not have to be unique and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CopyVolumeBackupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CopyVolumeBackupDetails.
        A user-friendly name for the volume backup. Does not have to be unique and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CopyVolumeBackupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this CopyVolumeBackupDetails.
        The OCID of the Key Management key in the destination region which will be the master encryption key
        for the copied volume backup.
        If you do not specify this attribute the volume backup will be encrypted with the Oracle-provided encryption
        key when it is copied to the destination region.


        For more information about the Key Management service and encryption keys, see
        `Overview of Key Management`__ and
        `Using Keys`__.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Tasks/usingkeys.htm


        :return: The kms_key_id of this CopyVolumeBackupDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this CopyVolumeBackupDetails.
        The OCID of the Key Management key in the destination region which will be the master encryption key
        for the copied volume backup.
        If you do not specify this attribute the volume backup will be encrypted with the Oracle-provided encryption
        key when it is copied to the destination region.


        For more information about the Key Management service and encryption keys, see
        `Overview of Key Management`__ and
        `Using Keys`__.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Tasks/usingkeys.htm


        :param kms_key_id: The kms_key_id of this CopyVolumeBackupDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateManagementSavedSearchDetails(object):
    """
    Properties of a saved search.
    """

    #: A constant which can be used with the type property of a CreateManagementSavedSearchDetails.
    #: This constant has a value of "SEARCH_SHOW_IN_DASHBOARD"
    TYPE_SEARCH_SHOW_IN_DASHBOARD = "SEARCH_SHOW_IN_DASHBOARD"

    #: A constant which can be used with the type property of a CreateManagementSavedSearchDetails.
    #: This constant has a value of "SEARCH_DONT_SHOW_IN_DASHBOARD"
    TYPE_SEARCH_DONT_SHOW_IN_DASHBOARD = "SEARCH_DONT_SHOW_IN_DASHBOARD"

    #: A constant which can be used with the type property of a CreateManagementSavedSearchDetails.
    #: This constant has a value of "WIDGET_SHOW_IN_DASHBOARD"
    TYPE_WIDGET_SHOW_IN_DASHBOARD = "WIDGET_SHOW_IN_DASHBOARD"

    #: A constant which can be used with the type property of a CreateManagementSavedSearchDetails.
    #: This constant has a value of "WIDGET_DONT_SHOW_IN_DASHBOARD"
    TYPE_WIDGET_DONT_SHOW_IN_DASHBOARD = "WIDGET_DONT_SHOW_IN_DASHBOARD"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateManagementSavedSearchDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CreateManagementSavedSearchDetails.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this CreateManagementSavedSearchDetails.
        :type display_name: str

        :param provider_id:
            The value to assign to the provider_id property of this CreateManagementSavedSearchDetails.
        :type provider_id: str

        :param provider_version:
            The value to assign to the provider_version property of this CreateManagementSavedSearchDetails.
        :type provider_version: str

        :param provider_name:
            The value to assign to the provider_name property of this CreateManagementSavedSearchDetails.
        :type provider_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateManagementSavedSearchDetails.
        :type compartment_id: str

        :param is_oob_saved_search:
            The value to assign to the is_oob_saved_search property of this CreateManagementSavedSearchDetails.
        :type is_oob_saved_search: bool

        :param description:
            The value to assign to the description property of this CreateManagementSavedSearchDetails.
        :type description: str

        :param nls:
            The value to assign to the nls property of this CreateManagementSavedSearchDetails.
        :type nls: object

        :param type:
            The value to assign to the type property of this CreateManagementSavedSearchDetails.
            Allowed values for this property are: "SEARCH_SHOW_IN_DASHBOARD", "SEARCH_DONT_SHOW_IN_DASHBOARD", "WIDGET_SHOW_IN_DASHBOARD", "WIDGET_DONT_SHOW_IN_DASHBOARD"
        :type type: str

        :param ui_config:
            The value to assign to the ui_config property of this CreateManagementSavedSearchDetails.
        :type ui_config: object

        :param data_config:
            The value to assign to the data_config property of this CreateManagementSavedSearchDetails.
        :type data_config: list[object]

        :param screen_image:
            The value to assign to the screen_image property of this CreateManagementSavedSearchDetails.
        :type screen_image: str

        :param metadata_version:
            The value to assign to the metadata_version property of this CreateManagementSavedSearchDetails.
        :type metadata_version: str

        :param widget_template:
            The value to assign to the widget_template property of this CreateManagementSavedSearchDetails.
        :type widget_template: str

        :param widget_vm:
            The value to assign to the widget_vm property of this CreateManagementSavedSearchDetails.
        :type widget_vm: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateManagementSavedSearchDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateManagementSavedSearchDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'provider_id': 'str',
            'provider_version': 'str',
            'provider_name': 'str',
            'compartment_id': 'str',
            'is_oob_saved_search': 'bool',
            'description': 'str',
            'nls': 'object',
            'type': 'str',
            'ui_config': 'object',
            'data_config': 'list[object]',
            'screen_image': 'str',
            'metadata_version': 'str',
            'widget_template': 'str',
            'widget_vm': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'provider_id': 'providerId',
            'provider_version': 'providerVersion',
            'provider_name': 'providerName',
            'compartment_id': 'compartmentId',
            'is_oob_saved_search': 'isOobSavedSearch',
            'description': 'description',
            'nls': 'nls',
            'type': 'type',
            'ui_config': 'uiConfig',
            'data_config': 'dataConfig',
            'screen_image': 'screenImage',
            'metadata_version': 'metadataVersion',
            'widget_template': 'widgetTemplate',
            'widget_vm': 'widgetVM',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._display_name = None
        self._provider_id = None
        self._provider_version = None
        self._provider_name = None
        self._compartment_id = None
        self._is_oob_saved_search = None
        self._description = None
        self._nls = None
        self._type = None
        self._ui_config = None
        self._data_config = None
        self._screen_image = None
        self._metadata_version = None
        self._widget_template = None
        self._widget_vm = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CreateManagementSavedSearchDetails.
        id for saved search.  Must be provided if OOB, otherwise must not be provided.


        :return: The id of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CreateManagementSavedSearchDetails.
        id for saved search.  Must be provided if OOB, otherwise must not be provided.


        :param id: The id of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateManagementSavedSearchDetails.
        Display name for saved search.


        :return: The display_name of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateManagementSavedSearchDetails.
        Display name for saved search.


        :param display_name: The display_name of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def provider_id(self):
        """
        **[Required]** Gets the provider_id of this CreateManagementSavedSearchDetails.
        Id for application (LA, APM, etc.) that owners this saved search.  Each owner has a unique Id.


        :return: The provider_id of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._provider_id

    @provider_id.setter
    def provider_id(self, provider_id):
        """
        Sets the provider_id of this CreateManagementSavedSearchDetails.
        Id for application (LA, APM, etc.) that owners this saved search.  Each owner has a unique Id.


        :param provider_id: The provider_id of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._provider_id = provider_id

    @property
    def provider_version(self):
        """
        **[Required]** Gets the provider_version of this CreateManagementSavedSearchDetails.
        Version.


        :return: The provider_version of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._provider_version

    @provider_version.setter
    def provider_version(self, provider_version):
        """
        Sets the provider_version of this CreateManagementSavedSearchDetails.
        Version.


        :param provider_version: The provider_version of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._provider_version = provider_version

    @property
    def provider_name(self):
        """
        **[Required]** Gets the provider_name of this CreateManagementSavedSearchDetails.
        Name for application (LA, APM, etc.) that owners this saved search.


        :return: The provider_name of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """
        Sets the provider_name of this CreateManagementSavedSearchDetails.
        Name for application (LA, APM, etc.) that owners this saved search.


        :param provider_name: The provider_name of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._provider_name = provider_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateManagementSavedSearchDetails.
        The ocid of the compartment that owns the saved search.


        :return: The compartment_id of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateManagementSavedSearchDetails.
        The ocid of the compartment that owns the saved search.


        :param compartment_id: The compartment_id of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_oob_saved_search(self):
        """
        **[Required]** Gets the is_oob_saved_search of this CreateManagementSavedSearchDetails.
        String boolean (\"true\" or \"false\") to indicate Out Of the Box saved search.


        :return: The is_oob_saved_search of this CreateManagementSavedSearchDetails.
        :rtype: bool
        """
        return self._is_oob_saved_search

    @is_oob_saved_search.setter
    def is_oob_saved_search(self, is_oob_saved_search):
        """
        Sets the is_oob_saved_search of this CreateManagementSavedSearchDetails.
        String boolean (\"true\" or \"false\") to indicate Out Of the Box saved search.


        :param is_oob_saved_search: The is_oob_saved_search of this CreateManagementSavedSearchDetails.
        :type: bool
        """
        self._is_oob_saved_search = is_oob_saved_search

    @property
    def description(self):
        """
        **[Required]** Gets the description of this CreateManagementSavedSearchDetails.
        Description.


        :return: The description of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateManagementSavedSearchDetails.
        Description.


        :param description: The description of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._description = description

    @property
    def nls(self):
        """
        **[Required]** Gets the nls of this CreateManagementSavedSearchDetails.
        Json for internationalization.


        :return: The nls of this CreateManagementSavedSearchDetails.
        :rtype: object
        """
        return self._nls

    @nls.setter
    def nls(self, nls):
        """
        Sets the nls of this CreateManagementSavedSearchDetails.
        Json for internationalization.


        :param nls: The nls of this CreateManagementSavedSearchDetails.
        :type: object
        """
        self._nls = nls

    @property
    def type(self):
        """
        **[Required]** Gets the type of this CreateManagementSavedSearchDetails.
        How to show the saved search.

        Allowed values for this property are: "SEARCH_SHOW_IN_DASHBOARD", "SEARCH_DONT_SHOW_IN_DASHBOARD", "WIDGET_SHOW_IN_DASHBOARD", "WIDGET_DONT_SHOW_IN_DASHBOARD"


        :return: The type of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CreateManagementSavedSearchDetails.
        How to show the saved search.


        :param type: The type of this CreateManagementSavedSearchDetails.
        :type: str
        """
        allowed_values = ["SEARCH_SHOW_IN_DASHBOARD", "SEARCH_DONT_SHOW_IN_DASHBOARD", "WIDGET_SHOW_IN_DASHBOARD", "WIDGET_DONT_SHOW_IN_DASHBOARD"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            raise ValueError(
                "Invalid value for `type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def ui_config(self):
        """
        **[Required]** Gets the ui_config of this CreateManagementSavedSearchDetails.
        Json to contain options for UI.


        :return: The ui_config of this CreateManagementSavedSearchDetails.
        :rtype: object
        """
        return self._ui_config

    @ui_config.setter
    def ui_config(self, ui_config):
        """
        Sets the ui_config of this CreateManagementSavedSearchDetails.
        Json to contain options for UI.


        :param ui_config: The ui_config of this CreateManagementSavedSearchDetails.
        :type: object
        """
        self._ui_config = ui_config

    @property
    def data_config(self):
        """
        **[Required]** Gets the data_config of this CreateManagementSavedSearchDetails.
        Array of Json to contain options for source of data.


        :return: The data_config of this CreateManagementSavedSearchDetails.
        :rtype: list[object]
        """
        return self._data_config

    @data_config.setter
    def data_config(self, data_config):
        """
        Sets the data_config of this CreateManagementSavedSearchDetails.
        Array of Json to contain options for source of data.


        :param data_config: The data_config of this CreateManagementSavedSearchDetails.
        :type: list[object]
        """
        self._data_config = data_config

    @property
    def screen_image(self):
        """
        **[Required]** Gets the screen_image of this CreateManagementSavedSearchDetails.
        Screenshot.


        :return: The screen_image of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._screen_image

    @screen_image.setter
    def screen_image(self, screen_image):
        """
        Sets the screen_image of this CreateManagementSavedSearchDetails.
        Screenshot.


        :param screen_image: The screen_image of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._screen_image = screen_image

    @property
    def metadata_version(self):
        """
        **[Required]** Gets the metadata_version of this CreateManagementSavedSearchDetails.
        Version of the metadata.


        :return: The metadata_version of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """
        Sets the metadata_version of this CreateManagementSavedSearchDetails.
        Version of the metadata.


        :param metadata_version: The metadata_version of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._metadata_version = metadata_version

    @property
    def widget_template(self):
        """
        **[Required]** Gets the widget_template of this CreateManagementSavedSearchDetails.
        Template.


        :return: The widget_template of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._widget_template

    @widget_template.setter
    def widget_template(self, widget_template):
        """
        Sets the widget_template of this CreateManagementSavedSearchDetails.
        Template.


        :param widget_template: The widget_template of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._widget_template = widget_template

    @property
    def widget_vm(self):
        """
        **[Required]** Gets the widget_vm of this CreateManagementSavedSearchDetails.
        View Model


        :return: The widget_vm of this CreateManagementSavedSearchDetails.
        :rtype: str
        """
        return self._widget_vm

    @widget_vm.setter
    def widget_vm(self, widget_vm):
        """
        Sets the widget_vm of this CreateManagementSavedSearchDetails.
        View Model


        :param widget_vm: The widget_vm of this CreateManagementSavedSearchDetails.
        :type: str
        """
        self._widget_vm = widget_vm

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateManagementSavedSearchDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateManagementSavedSearchDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateManagementSavedSearchDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateManagementSavedSearchDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateManagementSavedSearchDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateManagementSavedSearchDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateManagementSavedSearchDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateManagementSavedSearchDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Link(object):
    """
    The model for links.
    """

    #: A constant which can be used with the rel property of a Link.
    #: This constant has a value of "SELF"
    REL_SELF = "SELF"

    #: A constant which can be used with the rel property of a Link.
    #: This constant has a value of "CANONICAL"
    REL_CANONICAL = "CANONICAL"

    #: A constant which can be used with the rel property of a Link.
    #: This constant has a value of "NEXT"
    REL_NEXT = "NEXT"

    #: A constant which can be used with the rel property of a Link.
    #: This constant has a value of "TEMPLATE"
    REL_TEMPLATE = "TEMPLATE"

    #: A constant which can be used with the rel property of a Link.
    #: This constant has a value of "PREV"
    REL_PREV = "PREV"

    def __init__(self, **kwargs):
        """
        Initializes a new Link object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rel:
            The value to assign to the rel property of this Link.
            Allowed values for this property are: "SELF", "CANONICAL", "NEXT", "TEMPLATE", "PREV", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rel: str

        :param href:
            The value to assign to the href property of this Link.
        :type href: str

        """
        self.swagger_types = {
            'rel': 'str',
            'href': 'str'
        }

        self.attribute_map = {
            'rel': 'rel',
            'href': 'href'
        }

        self._rel = None
        self._href = None

    @property
    def rel(self):
        """
        Gets the rel of this Link.
        Reference links to the previous page, next page, and other pages.

        Allowed values for this property are: "SELF", "CANONICAL", "NEXT", "TEMPLATE", "PREV", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rel of this Link.
        :rtype: str
        """
        return self._rel

    @rel.setter
    def rel(self, rel):
        """
        Sets the rel of this Link.
        Reference links to the previous page, next page, and other pages.


        :param rel: The rel of this Link.
        :type: str
        """
        allowed_values = ["SELF", "CANONICAL", "NEXT", "TEMPLATE", "PREV"]
        if not value_allowed_none_or_none_sentinel(rel, allowed_values):
            rel = 'UNKNOWN_ENUM_VALUE'
        self._rel = rel

    @property
    def href(self):
        """
        Gets the href of this Link.
        The anchor tag.


        :return: The href of this Link.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this Link.
        The anchor tag.


        :param href: The href of this Link.
        :type: str
        """
        self._href = href

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ByoipRange(object):
    """
    A ByoipRange, is an IP address prefix that the user owns and wishes to import into OCI.
    """

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "CREATING"
    LIFECYCLE_DETAILS_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "VALIDATING"
    LIFECYCLE_DETAILS_VALIDATING = "VALIDATING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "PROVISIONED"
    LIFECYCLE_DETAILS_PROVISIONED = "PROVISIONED"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_DETAILS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "FAILED"
    LIFECYCLE_DETAILS_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "DELETING"
    LIFECYCLE_DETAILS_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_details property of a ByoipRange.
    #: This constant has a value of "DELETED"
    LIFECYCLE_DETAILS_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ByoipRange.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ByoipRange object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cidr_block:
            The value to assign to the cidr_block property of this ByoipRange.
        :type cidr_block: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ByoipRange.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this ByoipRange.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ByoipRange.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ByoipRange.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this ByoipRange.
        :type id: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ByoipRange.
            Allowed values for this property are: "CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ByoipRange.
            Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this ByoipRange.
        :type time_created: datetime

        :param time_validated:
            The value to assign to the time_validated property of this ByoipRange.
        :type time_validated: datetime

        :param time_advertised:
            The value to assign to the time_advertised property of this ByoipRange.
        :type time_advertised: datetime

        :param time_withdrawn:
            The value to assign to the time_withdrawn property of this ByoipRange.
        :type time_withdrawn: datetime

        :param validation_token:
            The value to assign to the validation_token property of this ByoipRange.
        :type validation_token: str

        """
        self.swagger_types = {
            'cidr_block': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_validated': 'datetime',
            'time_advertised': 'datetime',
            'time_withdrawn': 'datetime',
            'validation_token': 'str'
        }

        self.attribute_map = {
            'cidr_block': 'cidrBlock',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_validated': 'timeValidated',
            'time_advertised': 'timeAdvertised',
            'time_withdrawn': 'timeWithdrawn',
            'validation_token': 'validationToken'
        }

        self._cidr_block = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_validated = None
        self._time_advertised = None
        self._time_withdrawn = None
        self._validation_token = None

    @property
    def cidr_block(self):
        """
        **[Required]** Gets the cidr_block of this ByoipRange.
        The address range the user is on-boarding.


        :return: The cidr_block of this ByoipRange.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this ByoipRange.
        The address range the user is on-boarding.


        :param cidr_block: The cidr_block of this ByoipRange.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ByoipRange.
        The OCID of the compartment containing the Byoip Range.


        :return: The compartment_id of this ByoipRange.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ByoipRange.
        The OCID of the compartment containing the Byoip Range.


        :param compartment_id: The compartment_id of this ByoipRange.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ByoipRange.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ByoipRange.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ByoipRange.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ByoipRange.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this ByoipRange.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this ByoipRange.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ByoipRange.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this ByoipRange.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ByoipRange.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ByoipRange.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ByoipRange.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ByoipRange.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ByoipRange.
        The Oracle ID (OCID) of the Byoip Range.


        :return: The id of this ByoipRange.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ByoipRange.
        The Oracle ID (OCID) of the Byoip Range.


        :param id: The id of this ByoipRange.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ByoipRange.
        The Byoip Range's current substate.

        Allowed values for this property are: "CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_details of this ByoipRange.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ByoipRange.
        The Byoip Range's current substate.


        :param lifecycle_details: The lifecycle_details of this ByoipRange.
        :type: str
        """
        allowed_values = ["CREATING", "VALIDATING", "PROVISIONED", "ACTIVE", "FAILED", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_details, allowed_values):
            lifecycle_details = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ByoipRange.
        The Byoip Range's current state.

        Allowed values for this property are: "INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ByoipRange.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ByoipRange.
        The Byoip Range's current state.


        :param lifecycle_state: The lifecycle_state of this ByoipRange.
        :type: str
        """
        allowed_values = ["INACTIVE", "UPDATING", "ACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ByoipRange.
        The date and time the Byoip Range was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ByoipRange.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ByoipRange.
        The date and time the Byoip Range was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ByoipRange.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_validated(self):
        """
        Gets the time_validated of this ByoipRange.
        The date and time the Byoip Range was validated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_validated of this ByoipRange.
        :rtype: datetime
        """
        return self._time_validated

    @time_validated.setter
    def time_validated(self, time_validated):
        """
        Sets the time_validated of this ByoipRange.
        The date and time the Byoip Range was validated, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_validated: The time_validated of this ByoipRange.
        :type: datetime
        """
        self._time_validated = time_validated

    @property
    def time_advertised(self):
        """
        Gets the time_advertised of this ByoipRange.
        The date and time the Byoip Range was advertised, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_advertised of this ByoipRange.
        :rtype: datetime
        """
        return self._time_advertised

    @time_advertised.setter
    def time_advertised(self, time_advertised):
        """
        Sets the time_advertised of this ByoipRange.
        The date and time the Byoip Range was advertised, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_advertised: The time_advertised of this ByoipRange.
        :type: datetime
        """
        self._time_advertised = time_advertised

    @property
    def time_withdrawn(self):
        """
        Gets the time_withdrawn of this ByoipRange.
        The date and time the Byoip Range was withdrawn, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_withdrawn of this ByoipRange.
        :rtype: datetime
        """
        return self._time_withdrawn

    @time_withdrawn.setter
    def time_withdrawn(self, time_withdrawn):
        """
        Sets the time_withdrawn of this ByoipRange.
        The date and time the Byoip Range was withdrawn, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_withdrawn: The time_withdrawn of this ByoipRange.
        :type: datetime
        """
        self._time_withdrawn = time_withdrawn

    @property
    def validation_token(self):
        """
        **[Required]** Gets the validation_token of this ByoipRange.
        This is an internally generated ASCII string that the user will then use as part of the validation process. Specifically, they will need to add the token string generated by the service to their Internet Registry record.


        :return: The validation_token of this ByoipRange.
        :rtype: str
        """
        return self._validation_token

    @validation_token.setter
    def validation_token(self, validation_token):
        """
        Sets the validation_token of this ByoipRange.
        This is an internally generated ASCII string that the user will then use as part of the validation process. Specifically, they will need to add the token string generated by the service to their Internet Registry record.


        :param validation_token: The validation_token of this ByoipRange.
        :type: str
        """
        self._validation_token = validation_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
